==> core_models-0.1.0.gem: app/controllers/core_models/base/maritial_statuses_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class Base::MaritialStatusesController < CoreModelsController
    # GET /base/maritial_statuses
    # GET /base/maritial_statuses.json
    def index
      @base_maritial_statuses = Base::MaritialStatus.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @base_maritial_statuses }
      end
    end

    # GET /base/maritial_statuses/1
    # GET /base/maritial_statuses/1.json
    def show
      @base_maritial_status = Base::MaritialStatus.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @base_maritial_status }
      end
    end

    # GET /base/maritial_statuses/new
    # GET /base/maritial_statuses/new.json
    def new
      @base_maritial_status = Base::MaritialStatus.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @base_maritial_status }
      end
    end

    # GET /base/maritial_statuses/1/edit
    def edit
      @base_maritial_status = Base::MaritialStatus.find(params[:id])
    end

    # POST /base/maritial_statuses
    # POST /base/maritial_statuses.json
    def create
      @base_maritial_status = Base::MaritialStatus.new(params[:base_maritial_status])

      respond_to do |format|
        if @base_maritial_status.save
          format.html { redirect_to @base_maritial_status, :notice => 'Maritial status was successfully created.' }
          format.json { render :json => @base_maritial_status, :status => :created, :location => @base_maritial_status }
        else
          format.html { render :action => "new" }
          format.json { render :json => @base_maritial_status.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /base/maritial_statuses/1
    # PUT /base/maritial_statuses/1.json
    def update
      @base_maritial_status = Base::MaritialStatus.find(params[:id])

      respond_to do |format|
        if @base_maritial_status.update_attributes(params[:base_maritial_status])
          format.html { redirect_to @base_maritial_status, :notice => 'Maritial status was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @base_maritial_status.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /base/maritial_statuses/1
    # DELETE /base/maritial_statuses/1.json
    def destroy
      @base_maritial_status = Base::MaritialStatus.find(params[:id])
      @base_maritial_status.destroy

      respond_to do |format|
        format.html { redirect_to base_maritial_statuses_url }
        format.json { head :no_content }
      end
    end
  end
end

==> core_models-0.2.9.gem: app/controllers/core_models/base/maritial_statuses_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class Base::MaritialStatusesController < CoreModelsController
    # GET /base/maritial_statuses
    # GET /base/maritial_statuses.json
    def index
      @base_maritial_statuses = Base::MaritialStatus.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @base_maritial_statuses }
      end
    end

    # GET /base/maritial_statuses/1
    # GET /base/maritial_statuses/1.json
    def show
      @base_maritial_status = Base::MaritialStatus.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @base_maritial_status }
      end
    end

    # GET /base/maritial_statuses/new
    # GET /base/maritial_statuses/new.json
    def new
      @base_maritial_status = Base::MaritialStatus.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @base_maritial_status }
      end
    end

    # GET /base/maritial_statuses/1/edit
    def edit
      @base_maritial_status = Base::MaritialStatus.find(params[:id])
    end

    # POST /base/maritial_statuses
    # POST /base/maritial_statuses.json
    def create
      @base_maritial_status = Base::MaritialStatus.new(params[:base_maritial_status])

      respond_to do |format|
        if @base_maritial_status.save
          format.html { redirect_to @base_maritial_status, :notice => 'Maritial status was successfully created.' }
          format.json { render :json => @base_maritial_status, :status => :created, :location => @base_maritial_status }
        else
          format.html { render :action => "new" }
          format.json { render :json => @base_maritial_status.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /base/maritial_statuses/1
    # PUT /base/maritial_statuses/1.json
    def update
      @base_maritial_status = Base::MaritialStatus.find(params[:id])

      respond_to do |format|
        if @base_maritial_status.update(params[:base_maritial_status])
          format.html { redirect_to @base_maritial_status, :notice => 'Maritial status was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @base_maritial_status.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /base/maritial_statuses/1
    # DELETE /base/maritial_statuses/1.json
    def destroy
      @base_maritial_status = Base::MaritialStatus.find(params[:id])
      @base_maritial_status.destroy

      respond_to do |format|
        format.html { redirect_to base_maritial_statuses_url }
        format.json { head :no_content }
      end
    end
  end
end
